Added bridgin support for GSM and SIP
[lcr.git] / gsm.h
diff --git a/gsm.h b/gsm.h
index 3ecaf0d..254797e 100644 (file)
--- a/gsm.h
+++ b/gsm.h
@@ -15,6 +15,7 @@ enum {
 };
 
 struct lcr_gsm {
+       struct interface *interface;    /* interface this instance is associated to */
        struct lcr_gsm  *gsm_ms_next;   /* list of MS instances, in case of MS */
        char            name[16];       /* name of MS instance, in case of MS */
        int             type;           /* LCR_GSM_TYPE_*/
@@ -27,33 +28,38 @@ struct lcr_gsm {
 };
 
 /* GSM port class */
-class Pgsm : public PmISDN
+class Pgsm : public Port
 {
        public:
-       Pgsm(int type, struct mISDNport *mISDNport, char *portname, struct port_settings *settings, int channel, int exclusive, int mode);
+       Pgsm(int type, char *portname, struct port_settings *settings, struct interface *interface);
        ~Pgsm();
 
-       struct lcr_gsm *p_m_g_lcr_gsm; /* pointer to network/ms instance */
-       unsigned int p_m_g_callref; /* ref by OpenBSC/Osmocom-BB */
-       struct lcr_work p_m_g_delete; /* queue destruction of GSM port instance */
-       unsigned int p_m_g_mode; /* data/transparent mode */
-       int p_m_g_gsm_b_sock; /* gsm bchannel socket */
-       struct lcr_fd p_m_g_gsm_b_fd; /* event node */
-       int p_m_g_gsm_b_index; /* gsm bchannel socket index to use */
-       int p_m_g_gsm_b_active; /* gsm bchannel socket is activated */
-       struct lcr_msg *p_m_g_notify_pending;   /* queue for NOTIFY if not connected */
-       void *p_m_g_encoder, *p_m_g_decoder;    /* gsm handle */
-       signed short p_m_g_rxdata[160]; /* receive audio buffer */
-       int p_m_g_rxpos; /* position in audio buffer 0..159 */
-       int p_m_g_tch_connected; /* indicates if audio is connected */
+       char p_g_interface_name[64];
+       int p_g_tones; /* set, if tones are to be generated */
+       int p_g_earlyb; /* set, if patterns are available */
+       struct lcr_gsm *p_g_lcr_gsm; /* pointer to network/ms instance */
+       unsigned int p_g_callref; /* ref by OpenBSC/Osmocom-BB */
+       struct lcr_work p_g_delete; /* queue destruction of GSM port instance */
+       unsigned int p_g_mode; /* data/transparent mode */
+       int p_g_gsm_b_sock; /* gsm bchannel socket */
+       struct lcr_fd p_g_gsm_b_fd; /* event node */
+       int p_g_gsm_b_index; /* gsm bchannel socket index to use */
+       int p_g_gsm_b_active; /* gsm bchannel socket is activated */
+       struct lcr_msg *p_g_notify_pending;     /* queue for NOTIFY if not connected */
+       struct lcr_msg *p_g_setup_pending;      /* queue SETUP until RTP is created */
+       struct lcr_msg *p_g_connect_pending;    /* queue CONNECT until RTP is created and connected */
+       void *p_g_encoder, *p_g_decoder;        /* gsm handle */
+       signed short p_g_rxdata[160]; /* receive audio buffer */
+       int p_g_rxpos; /* position in audio buffer 0..159 */
+       int p_g_tch_connected; /* indicates if audio is connected */
 
-       void bchannel_close(void);
-       int bchannel_open(int index);
-       void bchannel_receive(struct mISDNhead *hh, unsigned char *data, int len);
-       void bchannel_send(unsigned int prim, unsigned int id, unsigned char *data, int len);
+       int p_g_rtp_bridge; /* if we use a bridge */
+       unsigned int p_g_rtp_ip_remote; /* stores ip */
+       unsigned short p_g_rtp_port_remote; /* stores port */
 
        void frame_send(void *_frame);
        void frame_receive(void *_frame);
+       int bridge_rx(unsigned char *data, int len);
 
        int hunt_bchannel(void);
        void call_conf_ind(unsigned int msg_type, unsigned int callref, struct gsm_mncc *gsm);
@@ -64,7 +70,10 @@ class Pgsm : public PmISDN
        void disc_ind(unsigned int msg_type, unsigned int callref, struct gsm_mncc *mncc);
        void rel_ind(unsigned int msg_type, unsigned int callref, struct gsm_mncc *mncc);
        void notify_ind(unsigned int msg_type, unsigned int callref, struct gsm_mncc *mncc);
+       void rtp_create_ind(unsigned int msg_type, unsigned int callref, struct gsm_mncc *mncc);
+       void rtp_connect_ind(unsigned int msg_type, unsigned int callref, struct gsm_mncc *mncc);
        void message_notify(unsigned int epoint_id, int message_id, union parameter *param);
+       void message_progress(unsigned int epoint_id, int message_id, union parameter *param);
        void message_alerting(unsigned int epoint_id, int message_id, union parameter *param);
        void message_connect(unsigned int epoint_id, int message_id, union parameter *param);
        void message_disconnect(unsigned int epoint_id, int message_id, union parameter *param);
@@ -74,7 +83,7 @@ class Pgsm : public PmISDN
 
 struct gsm_mncc *create_mncc(int msg_type, unsigned int callref);
 int send_and_free_mncc(struct lcr_gsm *lcr_gsm, unsigned int msg_type, void *data);
-void gsm_trace_header(struct mISDNport *mISDNport, class PmISDN *port, unsigned int msg_type, int direction);
+void gsm_trace_header(const char *interface_name, class Pgsm *port, unsigned int msg_type, int direction);
 int gsm_conf(struct gsm_conf *gsm_conf, char *conf_error);
 int gsm_exit(int rc);
 int gsm_init(void);